# Main Rapid cache module 

class RapidCache:
    def __init__(self):
        self.data_store = {}

    def set(self, key, value):
        """Set a value in the cache."""
        self.data_store[key] = value
        return True

    def get(self, key):
        """Get a value from the cache."""
        return self.data_store.get(key, None)
    
    def delete(self, key):
        """Delete a value from the cache."""
        if key in self.data_store:
            del self.data_store[key]
            return True
        return False
    
    def clear(self):
        """Clear the entire cache."""
        self.data_store.clear()
        return True
    

    


from setuptools import setup, find_packages

setup(
    name='rapid-redis',  
    version='0.1.0',
    description='A lightweight in-memory cache inspired by Redis (educational)',
    author='Atharsh K',
    author_email='atharshkrishnamoorthy@gmail.com',
    url='https://github.com/AtharshKrishnamoorthy/RAPID-REDIS.git',  
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3.7',
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)
